@@ -70,12 +70,12 @@ class Position(core.LdapObject):
     def add_occupant(self, user):
         """Ajouter un utilisateur occupant ce poste"""
         data = [(ldap.MOD_ADD, 'roleOccupant', user.dn.encode('utf-8'))]
-        consts.LDAP_CONN.modify_s(self.dn, data)
+        core.ldap_conn('modify_s', self.dn, data)
 
     def remove_occupant(self, user):
         """Retirer un utilisateur de la liste des personnes à ce poste"""
         data = [(ldap.MOD_DELETE, 'roleOccupant', user.dn.encode('utf-8'))]
-        consts.LDAP_CONN.modify_s(self.dn, data)
+        core.ldap_conn('modify_s', self.dn, data)
 
 
 class Department(core.LdapObject):
@@ -102,7 +102,7 @@ class Department(core.LdapObject):
     def add_role(self, name):
         """Créer un rôle dans ce département"""
         dn = 'cn={},{}'.format(name, self.dn)
-        consts.LDAP_CONN.add_s(dn, [('objectClass', b'organizationalRole')])
+        core.ldap_conn('add_s', dn, [('objectClass', b'organizationalRole')])
 
 
 class App(core.LdapObject):
@@ -227,7 +227,7 @@ class User(core.LdapObject):
             subdomain = kwargs.get('subdomain')
             if subdomain:
                 domain = 'ou={},{}'.format(subdomain, domain)
-            consts.LDAP_CONN.add_s('cn={0},{1}'.format(name, domain), data)
+            core.ldap_conn('add_s', 'cn={0},{1}'.format(name, domain), data)
             # utilisateur créé
             user = User(email)
             # maintenant on le rajoute dans le groupe des occupants du rôle
@@ -293,7 +293,7 @@ class User(core.LdapObject):
 
     def passwd(self, old_password, new_password):
         """Modification du mot de passe"""
-        consts.LDAP_CONN.passwd(self.dn, old_password, new_password)
+        core.ldap_conn('passwd_s', self.dn, old_password, new_password)
 
     def reset(self):
         """Reset du mot de passe"""
@@ -314,11 +314,11 @@ class User(core.LdapObject):
             (action, key, value.encode('utf-8'))
             for key, value in kwargs.items()
             ]
-        consts.LDAP_CONN.modify_s(self.dn, data)
+        core.ldap_conn('modify_s', self.dn, data)
 
     def delete(self):
         Position(self.employeeType).remove_occupant(self)
-        consts.LDAP_CONN.delete_s(self.dn)
+        core.ldap_conn('delete_s', self.dn)
 
     def apps_roles(self):
         """Retourne la liste des rôles spécifiques
@@ -385,7 +385,7 @@ class SystemAccount(core.LdapObject):
                 (key, value.encode('utf-8')) for key, value in data.items()
                 ]
             domain = consts.CONFIG['SystemAccount']['dn']
-            consts.LDAP_CONN.add_s(domain, data)
+            core.ldap_conn('add_s', domain, data)
             account = SystemAccount(username)
             account.reset()
 
@@ -436,7 +436,7 @@ class SystemAccount(core.LdapObject):
 
     def passwd(self, old_password, new_password):
         """Modification du mot de passe"""
-        consts.LDAP_CONN.passwd_s(self.dn, old_password, new_password)
+        core.ldap_conn('passwd_s', self.dn, old_password, new_password)
 
     def reset(self):
         """Reset du mot de passe"""
